# Primer Design in *Anopheles gambiae*
Primer Design in *Anopheles gambiae* taking into account SNP variation in primer binding sites, using primer3-py, malariagen_data and scikit-allel.

[![Open In Colab](https://colab.research.google.com/assets/colab-badge.svg)](https://colab.research.google.com/github/sanjaynagi/primerDesignAg/blob/main/Primer-Design-in-Anopheles-gambiae.ipynb)
